import { NgModule, Injectable, Injector } from '@angular/core';
import { HttpClient, HttpClientModule } from '@angular/common/http';
import { Observable } from 'rxjs';
import { Router, ActivatedRoute, RouterModule } from '@angular/router';
import { Title, BrowserModule } from '@angular/platform-browser';

/**
 * @fileoverview added by tsickle
 * Generated from: src/services/globals/globals.service.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/**
 * @abstract
 */
class XoGlobals {
}
if (false) {
    /**
     * @abstract
     * @return {?}
     */
    XoGlobals.prototype.appConfig = function () { };
    /**
     * @abstract
     * @return {?}
     */
    XoGlobals.prototype.apiCache = function () { };
}
class XoBrowserGlobals extends XoGlobals {
    /**
     * @return {?}
     */
    get appConfig() {
        return window['appConfig'] || (/** @type {?} */ ({}));
    }
    /**
     * @return {?}
     */
    get apiCache() {
        return window['apiCache'] || (/** @type {?} */ ({}));
    }
}
class XoNodeGlobals extends XoGlobals {
    /**
     * @return {?}
     */
    get appConfig() {
        return {};
    }
    /**
     * @return {?}
     */
    get apiCache() {
        return {};
    }
}
class XoGlobalsModule {
    /**
     * @return {?}
     */
    static forBrowser() {
        return {
            ngModule: XoGlobalsModule,
            providers: [
                { provide: XoGlobals, useClass: XoBrowserGlobals }
            ]
        };
    }
    /**
     * @return {?}
     */
    static forNode() {
        return {
            ngModule: XoGlobalsModule,
            providers: [
                { provide: XoGlobals, useClass: XoNodeGlobals }
            ]
        };
    }
}
XoGlobalsModule.decorators = [
    { type: NgModule, args: [{},] }
];

/**
 * @fileoverview added by tsickle
 * Generated from: src/services/api/apiRequest.service.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class XoApiRequestService {
    /**
     * @param {?} _globals
     * @param {?} _http
     */
    constructor(_globals, _http) {
        this._globals = _globals;
        this._http = _http;
        /**
         * Base path or URL of the Xo API.
         */
        this.apiUrl = '';
        if (('paths' in this._globals.appConfig)
            && ('apiUrl' in this._globals.appConfig.paths)) {
            this.apiUrl = this._globals.appConfig.paths.apiUrl;
        }
    }
    /**
     * Perform a GET request to the Xo API.
     *
     * @template T
     * @param {?} path Relative path of the API endpoint.
     * @param {?=} params Input parameters added to the GET request.
     * @param {?=} useCache Pro feature, optionally retrieve the item from apiCache.
     * @return {?}
     */
    get(path, params, useCache) {
        return this.cacheCheck(path, params, useCache, (/**
         * @return {?}
         */
        () => this._http.get(this.apiUrl + path, { params: params })));
    }
    /**
     * Perform a POST request to the Xo API.
     *
     * @template T
     * @param {?} path Relative path of the API endpoint.
     * @param {?} params Input parameters added to the POST request.
     * @param {?=} useCache Pro feature, optionally retrieve the item from apiCache.
     * @return {?}
     */
    post(path, params, useCache) {
        return this.cacheCheck(path, params, useCache, (/**
         * @return {?}
         */
        () => this._http.post(this.apiUrl + path, params)));
    }
    /**
     * @private
     * @template T
     * @param {?} url
     * @param {?} params
     * @param {?} useCache
     * @param {?} callback
     * @return {?}
     */
    cacheCheck(url, params, useCache, callback) {
        return new Observable((/**
         * @param {?} observer
         * @return {?}
         */
        (observer) => {
            const { next, error } = observer;
            /** @type {?} */
            const key = url + ((params) ? ':' + JSON.stringify(params) : '');
            if (((useCache) || (typeof useCache === 'undefined'))
                && (this._globals.apiCache[key])) {
                observer.next(this._globals.apiCache[key]);
            }
            else {
                if (callback) {
                    callback().subscribe((/**
                     * @param {?} response
                     * @return {?}
                     */
                    (response) => {
                        observer.next(response);
                    }));
                }
                else {
                    observer.error();
                }
            }
        }));
    }
}
XoApiRequestService.decorators = [
    { type: Injectable }
];
/** @nocollapse */
XoApiRequestService.ctorParameters = () => [
    { type: XoGlobals },
    { type: HttpClient }
];
if (false) {
    /**
     * Base path or URL of the Xo API.
     * @type {?}
     */
    XoApiRequestService.prototype.apiUrl;
    /** @type {?} */
    XoApiRequestService.prototype._globals;
    /** @type {?} */
    XoApiRequestService.prototype._http;
}

/**
 * @fileoverview added by tsickle
 * Generated from: src/services/api/api.service.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class XoApiService {
    /**
     * @param {?} _request
     */
    constructor(_request) {
        this._request = _request;
    }
}
XoApiService.decorators = [
    { type: Injectable }
];
/** @nocollapse */
XoApiService.ctorParameters = () => [
    { type: XoApiRequestService }
];
if (false) {
    /** @type {?} */
    XoApiService.prototype._request;
}

/**
 * @fileoverview added by tsickle
 * Generated from: src/services/api/config/config.service.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/**
 * Provide endpoints for retrieving the main site configuration.
 */
class XoApiConfigService extends XoApiService {
    /**
     * Get the main site configuration.
     * @param {?} name
     * @return {?}
     */
    get(name) {
        return this._request.get('/config/get');
    }
}
XoApiConfigService.decorators = [
    { type: Injectable }
];

/**
 * @fileoverview added by tsickle
 * Generated from: src/services/api/menus/menus.service.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/**
 * Provide endpoints for retrieving navigation menus.
 */
class XoApiMenusService extends XoApiService {
    /**
     * Get a navigation menu by location name.
     * @param {?} name
     * @return {?}
     */
    get(name) {
        return this._request.get('/menus/get', {
            menu: name
        });
    }
}
XoApiMenusService.decorators = [
    { type: Injectable }
];

/**
 * @fileoverview added by tsickle
 * Generated from: src/services/api/options/options.service.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/**
 * Provide endpoints for retrieving option groups.
 */
class XoApiOptionsService extends XoApiService {
    /**
     * Get an option group by name.
     * @param {?} name
     * @return {?}
     */
    get(name) {
        return this._request.get('/options/get', {
            name: name
        });
    }
}
XoApiOptionsService.decorators = [
    { type: Injectable }
];

/**
 * @fileoverview added by tsickle
 * Generated from: src/services/api/posts/posts.service.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/**
 * Provide endpoints for retrieving, searching, and listing various post types.
 */
class XoApiPostsService extends XoApiService {
    /**
     * Get a post using either the relative URL or postId.
     * @param {?} url
     * @return {?}
     */
    get(url) {
        return this._request.get('/posts/get', {
            url: url
        });
    }
    /**
     * Get a post draft or preview only if user logged in and can view.
     * @param {?} postId
     * @return {?}
     */
    getDraftOrPreview(postId) {
        return this._request.get('/posts/getDraftOrPreview', {
            postId: postId
        });
    }
    /**
     * Filter, search, or list posts by various properties similar to get_posts().
     * @param {?} params
     * @return {?}
     */
    filter(params) {
        return this._request.post('/posts/filter', params);
    }
    /**
     * Retrieve the config for a given post type.
     * @param {?} postType
     * @return {?}
     */
    config(postType) {
        return this._request.get('/posts/config', {
            postType: postType
        });
    }
}
XoApiPostsService.decorators = [
    { type: Injectable }
];

/**
 * @fileoverview added by tsickle
 * Generated from: src/services/api/routes/routes.service.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/**
 * Provide endpoints for retrieving dynamic routes and sitemap.
 */
class XoApiRoutesService extends XoApiService {
    /**
     * Get the dynamic route configuration.
     * @return {?}
     */
    get() {
        return this._request.get('/routes/get');
    }
    /**
     * Get breadcrumb sitemap entries for the given URL.
     * @param {?} url
     * @return {?}
     */
    breadcrumbs(url) {
        return this._request.get('/routes/breadcrumbs', {
            url: url
        });
    }
    /**
     * Get sitemap entries for posts and terms.
     * @return {?}
     */
    sitemap() {
        return this._request.get('/routes/sitemap');
    }
}
XoApiRoutesService.decorators = [
    { type: Injectable }
];

/**
 * @fileoverview added by tsickle
 * Generated from: src/services/api/terms/terms.service.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/**
 * Provide endpoints for filtering terms.
 */
class XoApiTermsService extends XoApiService {
    /**
     * Get a taxonomy and term by url.
     * @param {?} url
     * @return {?}
     */
    get(url) {
        return this._request.get('/terms/get', {
            url: url
        });
    }
    /**
     * Filter, search, or list terms by various properties similar to get_terms().
     * @param {?} params
     * @return {?}
     */
    filter(params) {
        return this._request.post('/terms/filter', params);
    }
}
XoApiTermsService.decorators = [
    { type: Injectable }
];

/**
 * @fileoverview added by tsickle
 * Generated from: src/services/routes/route.service.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class XoRouteService {
    /**
     * @param {?} _injector
     * @param {?} _routesService
     */
    constructor(_injector, _routesService) {
        this._injector = _injector;
        this._routesService = _routesService;
    }
    /**
     * @return {?}
     */
    getRoutes() {
        /** @type {?} */
        const router = this._injector.get(Router);
        return new Promise((/**
         * @param {?} resolve
         * @param {?} reject
         * @return {?}
         */
        (resolve, reject) => {
            this._routesService.get()
                .subscribe((/**
             * @param {?} response
             * @return {?}
             */
            (response) => {
                if (response.success)
                    router.resetConfig(response.routes);
                resolve(true);
            }));
        }));
    }
}
XoRouteService.decorators = [
    { type: Injectable }
];
/** @nocollapse */
XoRouteService.ctorParameters = () => [
    { type: Injector },
    { type: XoApiRoutesService }
];
if (false) {
    /**
     * @type {?}
     * @private
     */
    XoRouteService.prototype._injector;
    /**
     * @type {?}
     * @private
     */
    XoRouteService.prototype._routesService;
}
/**
 * @param {?} _routeService
 * @return {?}
 */
function XoInitRoutes(_routeService) {
    return (/**
     * @return {?}
     */
    () => _routeService.getRoutes());
}

/**
 * @fileoverview added by tsickle
 * Generated from: src/services/posts/post.resolver.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class XoPostResolver {
    /**
     * @param {?} _postService
     */
    constructor(_postService) {
        this._postService = _postService;
    }
    /**
     * @param {?} _route
     * @param {?} _state
     * @return {?}
     */
    resolve(_route, _state) {
        return new Promise((/**
         * @param {?} resolve
         * @param {?} reject
         * @return {?}
         */
        (resolve, reject) => {
            /** @type {?} */
            const onSubscribe = (/**
             * @param {?} response
             * @return {?}
             */
            (response) => {
                if (response.success)
                    resolve(response.post);
                reject();
            });
            if (_route.data.postId) {
                this._postService.getDraftOrPreview(_route.data.postId)
                    .subscribe(onSubscribe);
            }
            else if (_route.parent.data['postPreview']) {
                this._postService.getDraftOrPreview(_route.params['slug'])
                    .subscribe(onSubscribe);
            }
            else {
                /** @type {?} */
                const url = ((_route.data.url) ? (_route.data.url) : _state.url.split(/[?#]/)[0]);
                this._postService.get(url).subscribe(onSubscribe);
            }
        }));
    }
}
XoPostResolver.decorators = [
    { type: Injectable }
];
/** @nocollapse */
XoPostResolver.ctorParameters = () => [
    { type: XoApiPostsService }
];
if (false) {
    /**
     * @type {?}
     * @private
     */
    XoPostResolver.prototype._postService;
}

/**
 * @fileoverview added by tsickle
 * Generated from: src/components/posts/post.component.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class XoPostComponent {
    /**
     * @param {?} _router
     * @param {?} _route
     * @param {?} _title
     * @param {?} _globals
     */
    constructor(_router, _route, _title, _globals) {
        this._router = _router;
        this._route = _route;
        this._title = _title;
        this._globals = _globals;
        this._router.routeReuseStrategy.shouldReuseRoute = (/**
         * @return {?}
         */
        () => false);
    }
    /**
     * @return {?}
     */
    ngOnInit() {
        this.setPost();
    }
    /**
     * @return {?}
     */
    setPost() {
        if (this._route.snapshot.data['breadcrumbs']) {
            this.breadcrumbs = this._route.snapshot.data['breadcrumbs'];
        }
        if (this._route.snapshot.data['post']) {
            this.post = this._route.snapshot.data['post'];
            this.setTitle();
        }
    }
    /**
     * @return {?}
     */
    setTitle() {
        /** @type {?} */
        const title = ((this.post.title) ? this.post.title + ' | ' : '') + this._globals.appConfig.app.title;
        this._title.setTitle(title);
    }
}
XoPostComponent.decorators = [
    { type: Injectable }
];
/** @nocollapse */
XoPostComponent.ctorParameters = () => [
    { type: Router },
    { type: ActivatedRoute },
    { type: Title },
    { type: XoGlobals }
];
if (false) {
    /** @type {?} */
    XoPostComponent.prototype.breadcrumbs;
    /** @type {?} */
    XoPostComponent.prototype.post;
    /** @type {?} */
    XoPostComponent.prototype._router;
    /** @type {?} */
    XoPostComponent.prototype._route;
    /** @type {?} */
    XoPostComponent.prototype._title;
    /** @type {?} */
    XoPostComponent.prototype._globals;
}

/**
 * @fileoverview added by tsickle
 * Generated from: src/components/posts/postsList.component.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class XoPostsListComponent extends XoPostComponent {
    /**
     * @param {?} _router
     * @param {?} _route
     * @param {?} _title
     * @param {?} _globals
     * @param {?} _posts
     */
    constructor(_router, _route, _title, _globals, _posts) {
        super(_router, _route, _title, _globals);
        this._router = _router;
        this._route = _route;
        this._title = _title;
        this._globals = _globals;
        this._posts = _posts;
        this.posts = [];
        this.postsTotal = 0;
        this.pageCount = 0;
        this.postsFilterArgs = {
            currentPage: 1,
            postsPerPage: 10
        };
    }
    /**
     * @return {?}
     */
    ngOnInit() {
        this.post = this._route.snapshot.data['post'];
        this.getPosts();
    }
    /**
     * @return {?}
     */
    getPosts() {
        this._posts.filter(this.postsFilterArgs)
            .subscribe((/**
         * @param {?} response
         * @return {?}
         */
        (response) => {
            if (response.success) {
                this.posts = response.posts;
                this.postsTotal = response.total;
                this.setPageCount();
            }
        }));
    }
    /**
     * @return {?}
     */
    setPageCount() {
        if (this.postsFilterArgs.postsPerPage)
            this.pageCount = Math.ceil(this.postsTotal / this.postsFilterArgs.postsPerPage);
        else
            this.pageCount = 1;
    }
}
XoPostsListComponent.decorators = [
    { type: Injectable }
];
/** @nocollapse */
XoPostsListComponent.ctorParameters = () => [
    { type: Router },
    { type: ActivatedRoute },
    { type: Title },
    { type: XoGlobals },
    { type: XoApiPostsService }
];
if (false) {
    /** @type {?} */
    XoPostsListComponent.prototype.posts;
    /** @type {?} */
    XoPostsListComponent.prototype.postsTotal;
    /** @type {?} */
    XoPostsListComponent.prototype.pageCount;
    /** @type {?} */
    XoPostsListComponent.prototype.postsFilterArgs;
    /** @type {?} */
    XoPostsListComponent.prototype._router;
    /** @type {?} */
    XoPostsListComponent.prototype._route;
    /** @type {?} */
    XoPostsListComponent.prototype._title;
    /** @type {?} */
    XoPostsListComponent.prototype._globals;
    /** @type {?} */
    XoPostsListComponent.prototype._posts;
}

/**
 * @fileoverview added by tsickle
 * Generated from: src/components/posts/postTerm.component.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class XoPostTermComponent extends XoPostComponent {
    /**
     * @param {?} _router
     * @param {?} _route
     * @param {?} _title
     * @param {?} _globals
     */
    constructor(_router, _route, _title, _globals) {
        super(_router, _route, _title, _globals);
        this._router = _router;
        this._route = _route;
        this._title = _title;
        this._globals = _globals;
    }
    /**
     * @return {?}
     */
    ngOnInit() {
        this.setPost();
        this.setTerm();
    }
    /**
     * @return {?}
     */
    setTerm() {
        if (this._route.snapshot.data['term']) {
            this.term = this._route.snapshot.data['term'];
        }
    }
}
XoPostTermComponent.decorators = [
    { type: Injectable }
];
/** @nocollapse */
XoPostTermComponent.ctorParameters = () => [
    { type: Router },
    { type: ActivatedRoute },
    { type: Title },
    { type: XoGlobals }
];
if (false) {
    /** @type {?} */
    XoPostTermComponent.prototype.term;
    /** @type {?} */
    XoPostTermComponent.prototype._router;
    /** @type {?} */
    XoPostTermComponent.prototype._route;
    /** @type {?} */
    XoPostTermComponent.prototype._title;
    /** @type {?} */
    XoPostTermComponent.prototype._globals;
}

/**
 * @fileoverview added by tsickle
 * Generated from: src/services/terms/term.resolver.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class XoTermResolver {
    /**
     * @param {?} _termsService
     */
    constructor(_termsService) {
        this._termsService = _termsService;
    }
    /**
     * @param {?} _route
     * @param {?} _state
     * @return {?}
     */
    resolve(_route, _state) {
        return new Promise((/**
         * @param {?} resolve
         * @param {?} reject
         * @return {?}
         */
        (resolve, reject) => {
            /** @type {?} */
            const onSubscribe = (/**
             * @param {?} response
             * @return {?}
             */
            (response) => {
                if (response.success)
                    resolve(response.term);
                reject();
            });
            /** @type {?} */
            const url = ((_route.data.url) ? (_route.data.url) : _state.url.split(/[?#]/)[0]);
            this._termsService.get(url).subscribe(onSubscribe);
        }));
    }
}
XoTermResolver.decorators = [
    { type: Injectable }
];
/** @nocollapse */
XoTermResolver.ctorParameters = () => [
    { type: XoApiTermsService }
];
if (false) {
    /**
     * @type {?}
     * @private
     */
    XoTermResolver.prototype._termsService;
}

/**
 * @fileoverview added by tsickle
 * Generated from: src/components/terms/term.component.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class XoTermComponent {
    /**
     * @param {?} _router
     * @param {?} _route
     * @param {?} _title
     * @param {?} _globals
     */
    constructor(_router, _route, _title, _globals) {
        this._router = _router;
        this._route = _route;
        this._title = _title;
        this._globals = _globals;
        this._router.routeReuseStrategy.shouldReuseRoute = (/**
         * @return {?}
         */
        () => false);
    }
    /**
     * @return {?}
     */
    ngOnInit() {
        this.setTerm();
    }
    /**
     * @return {?}
     */
    setTerm() {
        if (this._route.snapshot.data['breadcrumbs']) {
            this.breadcrumbs = this._route.snapshot.data['breadcrumbs'];
        }
        if (this._route.snapshot.data['term']) {
            this.term = this._route.snapshot.data['term'];
            this.setTitle();
        }
    }
    /**
     * @return {?}
     */
    setTitle() {
        /** @type {?} */
        const title = ((this.term.name) ? this.term.name + ' | ' : '') + this._globals.appConfig.app.title;
        this._title.setTitle(title);
    }
}
XoTermComponent.decorators = [
    { type: Injectable }
];
/** @nocollapse */
XoTermComponent.ctorParameters = () => [
    { type: Router },
    { type: ActivatedRoute },
    { type: Title },
    { type: XoGlobals }
];
if (false) {
    /** @type {?} */
    XoTermComponent.prototype.breadcrumbs;
    /** @type {?} */
    XoTermComponent.prototype.term;
    /** @type {?} */
    XoTermComponent.prototype._router;
    /** @type {?} */
    XoTermComponent.prototype._route;
    /** @type {?} */
    XoTermComponent.prototype._title;
    /** @type {?} */
    XoTermComponent.prototype._globals;
}

/**
 * @fileoverview added by tsickle
 * Generated from: src/services/routes/breadcrumbs.resolver.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class XoBreadcrumbsResolver {
    /**
     * @param {?} _routesService
     */
    constructor(_routesService) {
        this._routesService = _routesService;
    }
    /**
     * @param {?} _route
     * @param {?} _state
     * @return {?}
     */
    resolve(_route, _state) {
        return new Promise((/**
         * @param {?} resolve
         * @param {?} reject
         * @return {?}
         */
        (resolve, reject) => {
            /** @type {?} */
            const onSubscribe = (/**
             * @param {?} response
             * @return {?}
             */
            (response) => {
                if (response.success)
                    resolve(response.breadcrumbs);
                resolve();
            });
            /** @type {?} */
            const url = ((_route.data.url) ? (_route.data.url) : _state.url.split(/[?#]/)[0]);
            this._routesService.breadcrumbs(url).subscribe(onSubscribe);
        }));
    }
}
XoBreadcrumbsResolver.decorators = [
    { type: Injectable }
];
/** @nocollapse */
XoBreadcrumbsResolver.ctorParameters = () => [
    { type: XoApiRoutesService }
];
if (false) {
    /**
     * @type {?}
     * @private
     */
    XoBreadcrumbsResolver.prototype._routesService;
}

/**
 * @fileoverview added by tsickle
 * Generated from: src/services/api/api.module.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class XoApiModule {
}
XoApiModule.decorators = [
    { type: NgModule, args: [{
                providers: [
                    XoApiService,
                    XoApiRequestService,
                    XoApiOptionsService,
                    XoApiMenusService,
                    XoApiPostsService,
                    XoApiTermsService,
                    XoApiRoutesService
                ]
            },] }
];

/**
 * @fileoverview added by tsickle
 * Generated from: src/angular-xo.module.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class XoModule {
}
XoModule.decorators = [
    { type: NgModule, args: [{
                imports: [
                    BrowserModule,
                    RouterModule,
                    HttpClientModule,
                    XoGlobalsModule.forBrowser(),
                    XoApiModule
                ],
                providers: [
                    XoRouteService,
                    XoPostResolver,
                    XoPostComponent,
                    XoPostsListComponent,
                    XoPostTermComponent,
                    XoTermResolver,
                    XoTermComponent,
                    XoBreadcrumbsResolver
                ]
            },] }
];

/**
 * @fileoverview added by tsickle
 * Generated from: public_api.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

/**
 * @fileoverview added by tsickle
 * Generated from: angular-xo.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

export { XoApiConfigService, XoApiMenusService, XoApiOptionsService, XoApiPostsService, XoApiRequestService, XoApiRoutesService, XoApiService, XoApiTermsService, XoBreadcrumbsResolver, XoGlobals, XoGlobalsModule, XoInitRoutes, XoModule, XoPostComponent, XoPostResolver, XoPostTermComponent, XoPostsListComponent, XoRouteService, XoTermComponent, XoTermResolver, XoBrowserGlobals as ɵa, XoNodeGlobals as ɵb, XoApiModule as ɵc };
//# sourceMappingURL=angular-xo.js.map
